pm4py.algo.conformance.alignments.process\_tree.variants.approximated package
=============================================================================

Submodules
----------

pm4py.algo.conformance.alignments.process\_tree.variants.approximated.calculate\_a\_sa\_ea\_sets module
-------------------------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.approximated.calculate_a_sa_ea_sets
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.process\_tree.variants.approximated.matrix\_lp module
---------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.approximated.matrix_lp
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.process\_tree.variants.approximated.original module
-------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.approximated.original
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.conformance.alignments.process\_tree.variants.approximated.utilities module
--------------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.approximated.utilities
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.process_tree.variants.approximated
   :members:
   :undoc-members:
   :show-inheritance:
